@@ -14,9 +14,14 @@
  */
 package org.apache.geode.codeAnalysis;
 
+import java.util.Optional;
 
-import org.apache.geode.redis.internal.GeodeRedisService;
+import org.junit.experimental.categories.Category;
 
+import org.apache.geode.redis.internal.RedisSanctionedSerializablesService;
+import org.apache.geode.test.junit.categories.SerializationTest;
+
+@Category(SerializationTest.class)
 public class AnalyzeRedisSerializablesIntegrationTest extends AnalyzeSerializablesJUnitTestBase {
 
   @Override
@@ -25,7 +30,7 @@ public class AnalyzeRedisSerializablesIntegrationTest extends AnalyzeSerializabl
   }
 
   @Override
-  protected Class getModuleClass() {
-    return GeodeRedisService.class;
+  protected Optional<Class<?>> getModuleClass() {
+    return Optional.of(RedisSanctionedSerializablesService.class);
   }
 }
