@@ -28,8 +28,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.HTTP_SERVICE_
 import static org.apache.geode.distributed.ConfigurationProperties.JMX_MANAGER;
 import static org.apache.geode.distributed.ConfigurationProperties.JMX_MANAGER_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.JMX_MANAGER_START;
-import static org.apache.geode.internal.AvailablePort.SOCKET;
-import static org.apache.geode.internal.AvailablePort.getRandomAvailablePort;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.getTimeout;
 import static org.apache.geode.test.dunit.IgnoredException.addIgnoredException;
@@ -157,7 +156,7 @@ public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
     }
 
     regionName = getUniqueName() + "Region";
-    jmxManagerPort = getRandomAvailablePort(SOCKET);
+    jmxManagerPort = getRandomAvailableTCPPort();
   }
 
   @After
@@ -317,7 +316,7 @@ public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
     vm2.invoke(() -> {
       Properties props = getDistributedSystemProperties();
       props.setProperty(JMX_MANAGER, "true");
-      props.setProperty(JMX_MANAGER_PORT, "1099");
+      props.setProperty(JMX_MANAGER_PORT, String.valueOf(jmxManagerPort));
       props.setProperty(JMX_MANAGER_START, "true");
       props.setProperty(HTTP_SERVICE_PORT, "0");
       getCache(props);
@@ -396,7 +395,7 @@ public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
     vm3.invoke(() -> {
       Properties props = getDistributedSystemProperties();
       props.setProperty(JMX_MANAGER, "true");
-      props.setProperty(JMX_MANAGER_PORT, "1099");
+      props.setProperty(JMX_MANAGER_PORT, String.valueOf(jmxManagerPort));
       props.setProperty(JMX_MANAGER_START, "true");
       props.setProperty(HTTP_SERVICE_PORT, "0");
       getCache(props);
@@ -877,43 +876,11 @@ public class PersistentRecoveryOrderDUnitTest extends CacheTestCase {
         Throwable thrown = catchThrowable(() -> {
           createReplicateRegion(regionName, getDiskDirs(getVMId()));
         });
-        assertThat(thrown)
-            .isInstanceOf(ConflictingPersistentDataException.class)
-            .hasMessageContaining("was not part of the same distributed system as the local data");
+        assertThat(thrown).isInstanceOf(ConflictingPersistentDataException.class);
       }
     });
   }
 
-  @Test
-  public void testRecoverableSplitBrain() {
-    vm2.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-    });
-    vm0.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      putEntry("A", "B");
-      getCache().getRegion(regionName).close();
-    });
-
-    vm1.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "B");
-      updateEntry("A", "C");
-      getCache().getRegion(regionName).close();
-    });
-
-    // VM0 doesn't know that VM1 ever existed so it will start up.
-    vm0.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "C");
-    });
-
-    vm1.invoke(() -> {
-      createReplicateRegion(regionName, getDiskDirs(getVMId()));
-      validateEntry("A", "C");
-    });
-  }
-
   /**
    * Test to make sure that if if a member crashes while a GII is in progress, we wait for the
    * member to come back for starting.
