@@ -23,14 +23,10 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
-import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 
 import org.apache.geode.CancelCriterion;
 import org.apache.geode.InternalGemFireError;
@@ -52,7 +48,7 @@ import org.apache.geode.internal.monitoring.ThreadsMonitoring;
 import org.apache.geode.internal.monitoring.ThreadsMonitoringImpl;
 import org.apache.geode.internal.monitoring.ThreadsMonitoringImplDummy;
 import org.apache.geode.internal.net.SocketCreator;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.logging.internal.executors.LoggingExecutors;
 
 /**
@@ -93,7 +89,8 @@ public class LonerDistributionManager implements DistributionManager {
     DistributionConfig config = system.getConfig();
 
     if (config.getThreadMonitorEnabled()) {
-      this.threadMonitor = new ThreadsMonitoringImpl(system);
+      this.threadMonitor = new ThreadsMonitoringImpl(system, config.getThreadMonitorInterval(),
+          config.getThreadMonitorTimeLimit());
       logger.info("[ThreadsMonitor] New Monitor object and process were created.\n");
     } else {
       this.threadMonitor = new ThreadsMonitoringImplDummy();
@@ -186,10 +183,10 @@ public class LonerDistributionManager implements DistributionManager {
 
   @Override // DM method
   public void retainMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
-      Version version) {
+      KnownVersion version) {
     for (Iterator<InternalDistributedMember> it = members.iterator(); it.hasNext();) {
       InternalDistributedMember id = it.next();
-      if (id.getVersionOrdinalObject().compareTo(version) < 0) {
+      if (id.getVersion().compareTo(version) < 0) {
         it.remove();
       }
     }
@@ -197,10 +194,10 @@ public class LonerDistributionManager implements DistributionManager {
 
   @Override // DM method
   public void removeMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
-      Version version) {
+      KnownVersion version) {
     for (Iterator<InternalDistributedMember> it = members.iterator(); it.hasNext();) {
       InternalDistributedMember id = it.next();
-      if (id.getVersionOrdinalObject().compareTo(version) >= 0) {
+      if (id.getVersion().compareTo(version) >= 0) {
         it.remove();
       }
     }
@@ -536,12 +533,7 @@ public class LonerDistributionManager implements DistributionManager {
     public void incLostLease() {}
 
     @Override
-    public long startSenderCreate() {
-      return 0L;
-    }
-
-    @Override
-    public void incSenders(boolean shared, boolean preserveOrder, long start) {}
+    public void incSenders(boolean shared, boolean preserveOrder) {}
 
     @Override
     public void decSenders(boolean shared, boolean preserveOrder) {}
@@ -1027,139 +1019,6 @@ public class LonerDistributionManager implements DistributionManager {
       return 0;
     }
   }
-  protected static class DummyExecutor implements ExecutorService {
-    @Override
-    public void execute(Runnable command) {
-      command.run();
-    }
-
-    @Override
-    public void shutdown() {}
-
-    @Override
-    public List<Runnable> shutdownNow() {
-      return Collections.emptyList();
-    }
-
-    @Override
-    public boolean isShutdown() {
-      return false;
-    }
-
-    @Override
-    public boolean isTerminated() {
-      return false;
-    }
-
-    @Override
-    public boolean awaitTermination(long timeout, TimeUnit unit) throws InterruptedException {
-      return true;
-    }
-
-    @Override
-    public <T> Future<T> submit(final Callable<T> task) {
-      Exception ex = null;
-      T result = null;
-      try {
-        result = task.call();
-      } catch (Exception e) {
-        ex = e;
-      }
-      return new CompletedFuture<T>(result, ex);
-    }
-
-    @Override
-    public <T> Future<T> submit(final Runnable task, final T result) {
-      return submit(new Callable<T>() {
-        @Override
-        public T call() throws Exception {
-          task.run();
-          return result;
-        }
-      });
-    }
-
-    @Override
-    public Future<?> submit(Runnable task) {
-      return submit(task, null);
-    }
-
-    @Override
-    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks)
-        throws InterruptedException {
-      List<Future<T>> results = new ArrayList<Future<T>>();
-      for (Callable<T> task : tasks) {
-        results.add(submit(task));
-      }
-      return results;
-    }
-
-    @Override
-    public <T> List<Future<T>> invokeAll(Collection<? extends Callable<T>> tasks, long timeout,
-        TimeUnit unit) throws InterruptedException {
-      return invokeAll(tasks);
-    }
-
-    @Override
-    public <T> T invokeAny(Collection<? extends Callable<T>> tasks)
-        throws InterruptedException, ExecutionException {
-
-      ExecutionException ex = null;
-      for (Callable<T> task : tasks) {
-        try {
-          return submit(task).get();
-        } catch (ExecutionException e) {
-          ex = e;
-        }
-      }
-      throw (ExecutionException) ex.fillInStackTrace();
-    }
-
-    @Override
-    public <T> T invokeAny(Collection<? extends Callable<T>> tasks, long timeout, TimeUnit unit)
-        throws InterruptedException, ExecutionException, TimeoutException {
-      return invokeAny(tasks);
-    }
-  }
-
-  private static class CompletedFuture<T> implements Future<T> {
-    private final T result;
-    private final Exception ex;
-
-    public CompletedFuture(T result, Exception ex) {
-      this.result = result;
-      this.ex = ex;
-    }
-
-    @Override
-    public boolean cancel(boolean mayInterruptIfRunning) {
-      return false;
-    }
-
-    @Override
-    public boolean isCancelled() {
-      return false;
-    }
-
-    @Override
-    public boolean isDone() {
-      return true;
-    }
-
-    @Override
-    public T get() throws InterruptedException, ExecutionException {
-      if (ex != null) {
-        throw new ExecutionException(ex);
-      }
-      return result;
-    }
-
-    @Override
-    public T get(long timeout, TimeUnit unit)
-        throws InterruptedException, ExecutionException, TimeoutException {
-      return get();
-    }
-  }
 
   @Override
   public void throwIfDistributionStopped() {
@@ -1394,6 +1253,10 @@ public class LonerDistributionManager implements DistributionManager {
     return getDistributionManagerIds();
   }
 
+  public Set<InternalDistributedMember> getLocatorDistributionManagerIds() {
+    return Collections.<InternalDistributedMember>emptySet();
+  }
+
   @Override
   public Map<InternalDistributedMember, Collection<String>> getAllHostedLocatorsWithSharedConfiguration() {
     return Collections.<InternalDistributedMember, Collection<String>>emptyMap();
