@@ -20,12 +20,12 @@ import org.apache.geode.internal.monitoring.ThreadsMonitoring;
 public class TestSerialGatewaySenderEventProcessor extends SerialGatewaySenderEventProcessor {
 
   public TestSerialGatewaySenderEventProcessor(AbstractGatewaySender sender, String id,
-      ThreadsMonitoring tMonitoring) {
-    super(sender, id, tMonitoring);
+      ThreadsMonitoring tMonitoring, boolean cleanQueues) {
+    super(sender, id, tMonitoring, cleanQueues);
   }
 
   @Override
-  protected void initializeMessageQueue(String id) {
+  protected void initializeMessageQueue(String id, boolean cleanQueues) {
     // Overridden to not create the RegionQueue in the constructor.
   }
 
